using System.ComponentModel.DataAnnotations;
using FluentEmail.Core;
using FluentEmail.Core.Models;
using Microsoft.VisualBasic;


namespace StockAdvisory;

public class StockEmailSender
{
    private IFluentEmailFactory _emailFactory;
    private IStockFormatter _formatter;

    public StockEmailSender(IFluentEmailFactory emailFactory, IStockFormatter formatter)
    {
        _emailFactory = emailFactory;
        _formatter = formatter;
    }

    public async Task<IEnumerable<SendResponse>> SendReports(ICollection<string> subscriberEmails,
        IEnumerable<StockDifferenceRecord> records)
    {
        var formattedRecords = _formatter.Format(records);
        if (formattedRecords == String.Empty)
        {
            return new List<SendResponse>();
        }
        IEnumerable<Task<SendResponse>> tasks = subscriberEmails.Select(subscriber =>
            _emailFactory.Create()
                .SetFrom("noreply@stockanalysis.testing")
                .To(subscriber)
                .Body(formattedRecords)
                .SendAsync()
        );
        return await Task.WhenAll(tasks);
    }
}