namespace StockAdvisory;

public class StockTextFormatter : IStockFormatter
{
    private const int SmallAlign = -12;
    private const int BigAlign = -30;

    public string Format(StockEntryRecord record)
    {
        // wouldnt this be better as to_string for the record? 
        return $"{record.Company,BigAlign}{record.Ticker,SmallAlign}" +
               $"{record.Shares,BigAlign}{record.Weight + "%",SmallAlign}" + Environment.NewLine;
    }

    public string Format(StockDifferenceRecord record)
    {
        var changeSymbol = record.SharesPercentChange > 0 ? " ▲ " : " ▼ ";
        // code repetition :/
        return $"{record.Company,BigAlign}{record.Ticker,SmallAlign}" +
               $"{record.Shares + $" ({changeSymbol + record.SharesPercentChange + "%)"}",BigAlign}" +
               $"{record.Weight + "%", SmallAlign}" + Environment.NewLine;
    }

    private string FormatHeader(bool includeChange)
    {
        var shares = "Shares" + (includeChange ? " (Change)" : "");
        
        return $"{"Company",BigAlign}{"Ticker",SmallAlign}" +
               $"{shares,BigAlign}{"Weight",SmallAlign}" + 
               Environment.NewLine;
    }

    public string Format(IEnumerable<StockEntryRecord> records)
    {
        return FormatHeader(false) +
               string.Join(Environment.NewLine, records.Select(Format));
    }

    public string Format(IEnumerable<StockDifferenceRecord> records)
    {
        return FormatHeader(true) +
               string.Join(Environment.NewLine, records.Select(Format));
    }
}